function [ p ] = bisection( f, a, b, Tol, Nmax )
% BISECTION Para determinar una solucin de la ecuacin f(x)=0, dada la funcin
% f continua en el intervalo [a,b] y los valores f(a), f(b) con signos opuestos.
%
% Parmetros:
%     f: Funcin de la que se busca encontrar una raz.
%     a: Extremo inicial del intervalo en el cual se buscar la raz.
%     b: Extremo final del intervalo sobre el que se buscar la raz.
%   Tol: Valor mnimo para el error absoluto entre los extremos del intervalo.
%  Nmax: Nmero mnimo de iteraciones a realizar antes de obtener una aproxima-
%        cin menor o igual a Tol y fallar.
%
%     p: Solucin aproximada a f(x) = 0 o mensaje de error.

FA = f(a);
i = 1;

while(i <= Nmax)
    p = a + (b-a)/2;
    FP = f(p);
    
    if((FP == 0) || ((b-a)/2 < Tol))
        disp(p);
        return
    end
    
    i = i + 1;
    
    if(FA * FP > 0)
        a = p;
        FA = FP;
    else
        b = p;
    end
end

error(['El mtodo fracas despus de %.d iteraciones. '...
       'Procedimiento terminado sin xito.'],Nmax);
end