function [ p ] = falseposition ( f, p0, p1, Tol, Nmax )
% FALSEPOSITION Para determinar una solucin de la ecuacin f(x)=0, dada
% la funcin f continua en el intervalo [p0,p1], donde los valores f(p0)
% y f(p1) tienen signos opuestos.
%
% Parmetros:
%    f: Funcin de la que se busca encontrar una raz.
%   p0: Primera aproximacin inicial a la raz de f.
%   p1: Segunda aproximacin inicial a la raz de f.
%  Tol: Error absoluto mnimo entre aproximaciones sucesivas.
% Nmax: Nmero mnimo de iteraciones a realizar antes de obtener una
%       aproximacin menor o igual a Tol y fallar.
%
%    p: Solucin aproximada a la raz de f.

q0 = f(p0);
q1 = f(p1);
i = 2;

while(i <= Nmax)
    p = p1 - q1*(p1-p0)/(q1-q0);
        
    if(abs(p - p1) < Tol)
        return
    end
    
    i = i + 1;
    q = f(p);
    if(q*q1<0)
        p0 = p1;
        q0 = q1;
    end
    p1 = p;
    q1 = f(p);
    
end

error(['El mtodo fracas despus de %.d iteraciones. '...
       'Procedimiento terminado sin xito.'],Nmax);
end