function [ p ] = muller ( f, x0, x1, x2, Tol, Nmax )
% MULLER Para obtener una solucin de la ecuacin f(x)=0 a travs del
% mtodo de Mller y las aproximaciones iniciales p0, p1 y p2.
%
% Parmetros:
%    f: Funcin de la que se busca encontrar una raz.
%   p0: Primera aproximacin inicial a la raz de f.
%   p1: Segunda aproximacin inicial para la raz de f.
%   p2: Tercera aproximacin inicial hacia la raz de f.
%  Tol: Error absoluto mnimo entre aproximaciones sucesivas.
% Nmax: Nmero mnimo de iteraciones a realizar antes de obtener una
%       aproximacin menor o igual a Tol y fallar.
%
%    p: Solucin aproximada a la raz de f.

i = 3;
h1 = x1 - x0;
h2 = x2 - x1;
d1 = (f(x1) - f(x0))/h1;
d2 = (f(x2) - f(x1))/h2;
d = (d2-d1)/(h2+h1);

while(i <= Nmax)
    b = d2+h2*d;
    D = sqrt(b^2-4*f(x2)*d);
    if(abs(b-D) < abs(b+D))
    	E = b + D;
    else
    	E = b - D;	
    end
    h = -2*f(x2)/E;
    p = x2+h;
    
    if(abs(h) < Tol)
        return
    end
    
    x0 = x1;
    x1 = x2;
    x2 = p;
    h1 = x1 - x0;
    h2 = x2 - x1;
    d1 = (f(x1) - f(x0))/h1;
    d2 = (f(x2) - f(x1))/h2;
    d = (d2-d1)/(h2+h1);
    i = i + 1;   
end
error(['El mtodo fracas despus de %.d iteraciones. '...
       'Procedimiento terminado sin xito.'],Nmax);
end