function [ p ] = newton( f, p0, Tol, Nmax )
% NEWTON Para obtener una solucin de la ecuacin f(x)=0 a travs del
% mtodo de Newton, a partir de la funcin diferenciable f y una apro-
% ximacin inicial p0.
%
% Parmetros:
%    f: Funcin diferenciable de la que se busca encontrar una raz.
%   p0: Aproximacin inicial a la raz de f.
%  Tol: Error absoluto mnimo entre aproximaciones sucesivas.
% Nmax: Nmero mnimo de iteraciones a realizar antes de obtener una
%       aproximacin menor o igual a Tol y fallar.
%
%    p: Solucin aproximada a la raz de f.

i = 1;

diff_f = inline(char(diff(char(f))));

while(i <= Nmax)
    p = p0 - (f(p0)/diff_f(p0));
    
    if(abs(p - p0) < Tol)
        return
    end
    i = i + 1;
    p0 = p;
end

error(['El mtodo fracas despus de %.d iteraciones. '...
       'Procedimiento terminado sin xito.'],Nmax);
end