function [ S ] = csfit( X, Y, dx0, dxn )
% CSFIT Para construir el spline cubico sujeto S(x) que interpola a la fun-
% cin f en los n+1 datos (x_k,y_k) para k = 0,1,...,n y que satisface las
% condiciones en los extremos, S'(x_0)=f'(x_0) y S'(x_n)=f'(x_n).
%
% Parmetros:
%   X: Vector de 1xn que contiene las abscisas de la funcin f y que adems
%      se cumple x_0 < x_1 < ... < x_n
%  FX: Vector de 1xn con las ordenadas de la funcin a interpolar y que se
%      corresponden con los valores de X.
% dx0: Valor de la derivada en el extremo izquierdo de la funcin f.
% dxn: Valor correspondiente al extremo derecho de f'(x_n).
%
%   S: Matriz con los coeficientes de S(x), en orden descendiente para cada
%      uno de los polinomios cbicos del spline.

n = length(X)-1;
H = diff(X);
A = H(2:n-1);
B = 2*(H(1:n-1)+H(2:n));
C = H(2:n);
D = diff(Y)./H;
U = 6*diff(D);
S = (zeros);

% Restricciones en los extremos (spline sujeto)
B(1) = B(1)-H(1)/2;
U(1) = U(1)-3*(D(1)-dx0);
B(n-1) = B(n-1)-H(n)/2;
U(n-1) = U(n-1)-3*(dxn-D(n));

for k=2:n-1
    temp = A(k-1)/B(k-1);
    B(k) = B(k)-temp*C(k-1);
    U(k) = U(k)-temp*U(k-1);
end

M(n) = U(n-1)/B(n-1);
for k=n-2:-1:1
    M(k+1) = (U(k)-C(k)*M(k+2))/B(k);
end

% Ecuaciones para m_0 y m_n (spline sujeto)
M(1) = 3*(D(1)-dx0)/H(1)-M(2)/2;
M(n+1) = 3*(dxn-D(n))/H(n)-M(n)/2;

for k=0:n-1
    S(k+1,1) = (M(k+2)-M(k+1))/(6*H(k+1));
    S(k+1,2) = M(k+1)/2;
    S(k+1,3) = D(k+1)-H(k+1)*(2*M(k+1)+M(k+2))/6;
    S(k+1,4) = Y(k+1);
end
end