function [ QD ] = hermite ( x, X, FX, FPX )
% HERMITE Para obtener los coeficientes del polinomio interpolante de
% Hermite H(x), en los n+1 nmeros distintos x_0,x_1,...,x_n para la
% funcin f.
%
% Parmetros:
%    x: El punto donde se evaluar el polinomio.
%    X: Vector que contiene las abscisas de la funcin f a interpolar.
%   FX: Vector con las ordenadas de f, correspondientes a los valores
%       del vector X.
%  FPX: Vector con los valores de f'(x), para toda x en el vector X.
%
%   QD: Vector con los coeficientes de H(x), donde Q(i,i) = QD(i) pa-
%       ra i=0,1,...,2n+1.

[~, n] = size(X);
QD = (zeros);
Z = (zeros);
Q = [[],[]];
h = 0;

for i=0:n-1
    Z(2*i+1) = X(i+1);
    Z(2*i+2) = X(i+1);
    Q(2*i+1,1) = FX(i+1);
    Q(2*i+2,1) = FX(i+1);
    Q(2*i+2,2) = FPX(i+1);
    if(i ~= 0)
        Q(2*i+1,2) = (Q(2*i+1,1) - Q(2*i,1))/(Z(2*i+1)-Z(2*i));
    end
end

for i=3:2*n
    for j=3:i
        Q(i, j) = (Q(i,j-1)-Q(i-1,j-1))/(Z(i) - Z(i-j+1));
    end
end

for k=1:2*n
    QD(k) = Q(k,k);
    d = 1;
    for r=1:k-1
        d = d*(x-Z(r));
    end
    h = h + d*QD(k);
end

% H(x), el polinomio interpolante de Hermite evaluado en x
h