function [ Q ] = neville ( x, X, FX )
% NEVILLE Para evaluar el polinomio interpolante P de los n + 1
% nmeros distintos x0,x1,...,xn en el valor x de la funcin f.
%
% Parmetros:
%   x: El punto donde se evaluar el polinomio.
%   X: Vector que contiene las abscisas en las que se conoce f.
%  FX: Vector con las ordenadas de f, correspondientes a los va-
%      lores del vector X.
%
%   Q: Las aproximaciones de P a f(x), donde Q_(k,1) = FX(k) y
%      Q_(n,n) = P(x).

[~, n] = size(X);
Q = [[],[]];

for k=1:n
    Q(k,1) = FX(k);
end

for i=2:n
    for j=2:i
        Q(i, j) = ((x-X(i-j+1))*Q(i,j-1)-(x-X(i))*Q(i-1,j-1))/(X(i)-X(i-j+1));
    end
end