function [ FD ] = newton ( x, X, FX )
% NEWTON Para obtener los coeficientes de las diferencias dividi-
% das del polinomio interpolantes P en los n+1 numeros distintos
% x_0,x_1,...,x_n para la funcin f.
%
% Parmetros:
%   x: El punto donde se evaluar el polinomio.
%   X: Vector que contiene las abscisas en las que se conoce f.
%  FX: Vector con las ordenadas de f, correspondientes a los va-
%      lores del vector X.
%
%  FD: Vector de diferencias divididas, F(i,i) = f[x_0,...,x_i].

[~, n] = size(X);
FD = (zeros);
F = [[],[]];
p = 0;

for k=1:n
    F(k,1) = FX(k);
end

for i=2:n
    for j=2:i
        F(i, j) = (F(i,j-1)-F(i-1,j-1))/(X(i)-X(i-j+1));
    end
end

for k=1:n
    FD(k) = F(k,k);
    d = 1;
    for r=1:k-1
        d = d*(x-X(r));
    end
    p = p + d*FD(k);
end

% P(x), el polinomio interpolante de Newton evaluado en x
p