function [ S, E ] = golden( f, a, b, delta, epsilon )
% GOLDEN Para determinar un mnimo de la funcin unimodal f, en el inter-
% valo [a,b], a travs del mtodo de la razn urea.
%
% Parmetros:
%        f: Funcin unimodal de la que se busca encontrar un mnimo.
%        a: Extremo inicial del intervalo en el cual se buscar el mnimo.
%        b: Extremo final del intervalo sobre el que se buscar el mnimo.
%    delta: Tolerancia del error para las abscisas.
%  epsilon: Tolerancia para el error en las ordenadas.
%
%       S: Vector de 1 x 2 que contiene la ordena y la abscisa del mnimo.
%       E: Error absoluto entre los extremos del intervalo y de las imge-
%          de stos en la funcin f.

r1 = (sqrt(5)-1)/2;
r2 = r1^2;
h = b-a;
ya = f(a);
yb = f(b);
c = a + r2*h;
d = a + r1*h;
yc = f(c);
yd = f(d);
k = 1;
A(k) = a;B(k) = b;C(k) = c;D(k) = d;

while(abs(yb-ya)>epsilon)||(h>delta)
    k = k+1;
    if(yc < yd)
        b = d;
        yb = yd;
        d = c;
        yd = yc;
        h = b-a;
        c = a+r2*h;
        yc = f(c);
    else
        a = c;
        ya = yc;
        c = d;
        yc = yd;
        h = b-a;
        d = a+r1*h;
        yd = f(d);
    end
    A(k) = a;B(k) = b;C(k) = c;D(k) =d;
end
dp = abs(b-a);
dy = abs(yb-ya);

p = a;
yp = ya;
if(yb < ya)
    p = b;
    yp = yb;
end

G = [A' C' D' B'];
S = [p yp];
E = [dp dy];
end