function [ V0, y0, dV] = nelder( F, V, min1, max1, epsilon, varnames )
% NELDER Para aproximar un mnimo local de una funcin escalar de R^n -> R,
% a partir de los n+1 vectores V_k=(v_k1,...,v_kn) que conforman el smplex
% inicial.
%
% Parmetros:
%        F: Funcin de la que se busca encontrar un mnimo local, introduci-
%           da como una cadena de caracteres.
%        V: Matriz de (n+1) x n, en donde cada rengln contiene los vrtices
%           del smplex inicial.
%     min1: Nmero mnimo de iteraciones a realizar antes de poder concluir
%           la ejecucin del mtodo.
%     max1: Nmero mximo de iteraciones a realizar para despus poder fina-
%           lizar la ejecucin del mtodo.
%  epsilon: Tolerancia del error para el mnimo de la funcin.
% varnames: Caracteres de las variables para las funciones coordenadas de F, 
%           en un vector de 1 x n.
%
%       V0: Vrtice en el que se alcanza el mnimo.
%       y0: Valor mnimo de la funcin, F(V0).
%       dV: Estimacin del volmen del smplex final.

[~, n] = size(V);

varnamescell = num2cell(varnames);
Vcell = num2cell(V);
F = inline(F,varnamescell{:});
Y = (zeros);
Q = (zeros);

for j=1:n+1
    Y(j) = F(Vcell{j,:});
end

[~, lo] = min(Y);
[~, hi] = max(Y);
li = hi;
ho = lo;

for j=1:n+1
    if(j~=lo && j~=hi && Y(j)<=Y(li))
        li = j;
    end
    if (j~=hi && j~=lo && Y(j)>=Y(ho))
        ho = j;
    end
end
cnt = 0;


while(Y(hi)>Y(lo)+epsilon && cnt<max1) || cnt<min1
    S = zeros(1,n);
    
    for j=1:n+1
        S = S + V(j,:);
    end
    
    M = (S - V(hi,:))/n;
    R = 2 * M - V(hi,:);
    Rcell = num2cell(R);
    yR = F(Rcell{:});
    
    if(yR<Y(ho))
        if(Y(li)<yR)
            V(hi,:) = R;
            Y(hi) = yR;
        else
            E = 2 * R - M;
            Ecell = num2cell(E);
            yE = F(Ecell{:});
            if(yE<Y(li))
                V(hi,:) = E;
                Y(hi) = yE;
            else
                V(hi,:) = R;
                Y(hi) = yR;
            end
        end
    else
        if(yR<Y(hi))
            V(hi,:) = R;
            Y(hi) = yR;
        end
        C = (V(hi,:)+M)/2;
        Ccell = num2cell(C);
        yC = F(Ccell{:});
        C2 = (M+R)/2;
        C2cell = num2cell(C2);
        yC2 = F(C2cell{:});
        if(yC2<yC)
            C = C2;
            yC = yC2;
        end
        if(yC<Y(hi))
            V(hi,:) = C;
            Y(hi) = yC;
        else
            
            for j=1:n+1
                if(j~=lo)
                    V(j,:) = (V(j,:) + V(lo,:))/2;
                    Vjcell = num2cell(V);
                    Y(j) = F(Vjcell{j,:});
                end
            end
        end
    end
    
    [~, lo] = min(Y);
    [~, hi] = max(Y);
    li = hi;
    ho = lo;
    
    for j=1:n+1
        if(j~=lo && j~=hi && Y(j)<=Y(li))
            li = j;
        end
        if (j~=hi && j~=lo && Y(j)>=Y(ho))
            ho = j;
        end
    end
    cnt = cnt + 1;
end

%Estimacin del volmen del smplex
snorm = 0;
for j=1:n+1
    s = norm(V(j)-V(lo));
    if(s>=snorm)
        snorm = s;
    end
end
dV = snorm;

V0 = V(lo,:);
y0 = Y(lo);
end