function [ x ] = descent( G, p0, Tol, Nmax, varnames )
% DESCENT Para aproximar una solucin al punto mnimo de una funcin escalar
% de R^n->R, a partir de una aproximacin inicial p0.
%
% Parmetros:
%        G: Funcin de R^n->R para la que se desea encontrar un mnimo, expre-
%           sada como una cadena de caracteres.
%       p0: Aproximacin inicial, como un vector de 1 x n.
%      Tol: Error absoluto mnimo entre aproximaciones sucesivas.
%     Nmax: Nmero mnimo de iteraciones a realizar antes de obtener una apro-
%           ximacin o fallar.
% varnames: Caracteres de las variables para las funciones coordenadas de F,
%           en un vector de 1 x n.
%
%        x: Solucin aproximada al mnimo de la funcin G, o mensaje de error.

varnamescell = num2cell(varnames);
gfunc = inline(G,varnamescell{:});
[~, n] = size(p0);
z = [zeros];
x = p0';
k = 0;

while(k <= Nmax)
    
    xcell = num2cell(x);
    g1 = gfunc(xcell{:});
    
    % z = dG(x)
    for j=1:n
        zj = inline(char(diff(sym(G),varnames(j))),varnamescell{:});
        z(j) = zj(xcell{:});
    end
    
    % z0 = ||z||_2
    z0 = 0;
    for j=1:n
        z0 = z0 + z(j)^2;
    end
    z0 = sqrt(z0);
    
    if(z0 == 0)
        disp('GRADIENTE CERO');
        disp('Proceso completado, podra tener un mnimo. Revisar');
        g1
        return;
    end
    
    z = z/z0;
    alpha1 = 0;
    alpha3 = 1;
    % g3 = G(x - alpha3*z)
    inputcell = {};
    for j=1:n
        inputcell{j} = xcell{j} - alpha3*(z(j));
    end
    g3 = gfunc(inputcell{:});
    
    while(abs(g3) >= abs(g1))
        alpha3 = alpha3/2;
        % g3 = G(x - alpha3*z)
        inputcell = {};
        for j=1:n
            inputcell{j} = xcell{j} - alpha3*(z(j));
        end
        g3 = gfunc(inputcell{:});
              
        if(alpha3 < (Tol/2))
            disp('NO HAY MEJORA SIGNIFICATIVA');
            disp('Proceso completado, podra tener un mnimo. Revisar');
            g1
            return;
        end
    end
    
    alpha2 = alpha3/2;
    % g2 = G(x - alpha2*z)
    inputcell = {};
    for j=1:n
        inputcell{j} = xcell{j} - alpha2*(z(j));
    end
    g2 = gfunc(inputcell{:});
       
    h1 = (g2 - g1)/alpha2;
    h2 = (g3 - g2)/(alpha3 - alpha2);
    h3 = (h2 - h1)/alpha3;
    
    alpha0 = 0.5*(alpha2 - h1/h3);
    % g0 = G(x - alpha0*z)
    inputcell = {};
    for j=1:n
        inputcell{j} = xcell{j} - alpha0*(z(j));
    end
    g0 = gfunc(inputcell{:});
    
    g = min([g0, g1, g2, g3]);
    % Obtener alpha tal que g = G(x - alpha*z)
    if(g == g0)
        alpha = alpha0;
    elseif(g == g1)
        alpha = alpha1;
    elseif(g == g2)
        alpha = alpha2;
    elseif(g == g3)
        alpha = alpha3;
    end
    
    x = x' - alpha*z;
    x = x';
    
    if(abs(g - g1) < Tol)
        disp('Proceso completado con xito.');
        g1
        return;
    end
    
    k = k + 1;
end

error(['El mtodo fracas despus de %.d iteraciones. '...
       'Procedimiento terminado sin xito.'],Nmax);
end