function [ x ] = newton( F, x0, Tol, Nmax, varnames )
% NEWTON Para aproximar una solucin de un sistema de ecuaciones no lineales
% escrito en notacin vectorial F(x)=0, a partir de una aproximacin inicial
% x0.
%
% Parmetros:
%        F: Funcin de R^n->R^n para la que se desea encontrar una solucin;
%           dada como una matriz de celdas de 1 x n, donde las celdas son ca-
%           denas de caracteres que representan las n funciones coordenadas.
%       x0: Aproximacin inicial, como un vector de 1 x n.
%      Tol: Error absoluto mnimo entre aproximaciones sucesivas.
%     Nmax: Nmero mnimo de iteraciones a realizar antes de obtener una apro-
%           ximacin o fallar.
% varnames: Caracteres de las variables para las funciones coordenadas de F, 
%           en un vector de 1 x n.
%
%        x: Solucin aproximada a F, o mensaje de error.

varnamescell = num2cell(varnames);
[~, n] = size(x0);
x0 = x0';
i = 1;

while(i <= Nmax)

    x0cell = num2cell(x0);
    
    % Clculo de F(x0)
    f = [];
    for j=1:n
        fj = inline(char(F(j)),varnamescell{:});
        f(j) = fj(x0cell{:});
    end
    
    % Clculo de J(x0)
    J = [];
    for j=1:n
        for k=1:n
            fjdiffk = inline(char(diff(sym(F(j)),varnames(k))),varnamescell{:});
            J(j,k) = fjdiffk(x0cell{:});
        end
    end
    
    % Sintaxis para resolver el sistema lineal, J(x0)y=-F(x0)
    y = J \ -f';
    
    x = x0 + y;
    
    norm_infty = norm(x-x0,inf);
    
    if(norm_infty < Tol)
        return
    end
    
    i = i + 1;
    x0 = x;
end

error(['El mtodo fracas despus de %.d iteraciones. '...
       'Procedimiento terminado sin xito.'],Nmax);
end