function [ p ] = seidel( G, p0, Tol, Nmax, varnames )
% SEIDEL Para determinar una solucin de un sistema de ecuaciones no lineales,
% expresado como un problema de punto fijo; a travs de la tcnica de Gauss-
% Seidel para acelerar la convergencia.
%
% Parmetros:
%        G: Funcin de R^n->R^n para la que se desea encontrar un punto fijo;
%           dada como una matriz de celdas de 1 x n, donde las celdas son ca-
%           denas de caracteres que representan las n funciones coordenadas.
%       p0: Aproximacin inicial al punto fijo, como un vector de 1 x n.
%      Tol: Error absoluto mnimo entre aproximaciones sucesivas.
%     Nmax: Nmero mnimo de iteraciones a realizar antes de obtener una apro-
%           ximacin o fallar.
% varnames: Caracteres de las variables para las funciones coordenadas de G,  
%           en un vector de 1 x n.
%
%        p: Solucin aproximada al punto fijo de G, como un vector de n x 1 o
%           mensaje de error.

varnamescell = num2cell(varnames);
[~, n] = size(p0);
p = [];
i = 1;

while(i <= Nmax)
    
    p0cell = num2cell(p0);
    
    % Clculo de la aproximacin p = G(p0)
    pcell = {};
    for j=1:n
        gj = inline(char(G(j)),varnamescell{:});
        pcell{j} = gj(pcell{1:j-1}, p0cell{j:n});
        p(j) = pcell{j};
    end
    
    norm_infty = norm(p-p0,inf);
    
    if(norm_infty < Tol)
        p = p';
        return
    end
    
    i = i + 1;
    p0 = p;
end

error(['El mtodo fracas despus de %.d iteraciones. '...
       'Procedimiento terminado sin xito.'],Nmax);
end